@@ -147,7 +147,7 @@ async fn test_routine_leak_on_close() -> Result<()> {
     assert_eq!(n_a, 100);
 
     let mut buf_b = vec![0; 1024];
-    let n_b = cb.read(&mut buf_b, Some(Duration::from_secs(5))).await?;
+    let (n_b, _) = cb.read(&mut buf_b, Some(Duration::from_secs(5))).await?;
     assert_eq!(n_a, 100);
     assert_eq!(&buf_a[..], &buf_b[0..n_b]);
 
@@ -193,7 +193,7 @@ async fn test_sequence_number_overflow_on_application_data() -> Result<()> {
     assert_eq!(n_a, 100);
 
     let mut buf_b = vec![0; 1024];
-    let n_b = cb.read(&mut buf_b, Some(Duration::from_secs(5))).await?;
+    let (n_b, _) = cb.read(&mut buf_b, Some(Duration::from_secs(5))).await?;
     assert_eq!(n_a, 100);
     assert_eq!(&buf_a[..], &buf_b[0..n_b]);
 
@@ -409,8 +409,10 @@ async fn test_export_keying_material() -> Result<()> {
     let (_handshake_tx, handshake_rx) = mpsc::channel(1);
     let (packet_tx, _packet_rx) = mpsc::channel(1);
     let (handle_queue_tx, _handle_queue_rx) = mpsc::channel(1);
+    let (ca, _cb) = pipe();
 
     let mut c = DTLSConn {
+        conn: Arc::new(ca),
         state: State {
             local_random: HandshakeRandom {
                 gmt_unix_time: SystemTime::UNIX_EPOCH
