@@ -135,16 +135,13 @@ pub enum Error {
     #[error("Alert is Fatal or Close Notify")]
     ErrAlertFatalOrClose,
 
-    #[error("Other errors: {0}")]
-    ErrOthers(String),
+    #[allow(non_camel_case_types)]
+    #[error("{0}")]
+    new(String),
 }
 
 impl Error {
     pub fn equal(&self, err: &anyhow::Error) -> bool {
-        if let Some(e) = err.downcast_ref::<Self>() {
-            e == self
-        } else {
-            false
-        }
+        err.downcast_ref::<Self>().map_or(false, |e| e == self)
     }
 }
