@@ -3,7 +3,7 @@ use super::*;
 use std::io::{BufReader, BufWriter};
 
 #[test]
-fn test_extension_supported_groups() -> Result<(), Error> {
+fn test_extension_supported_groups() -> Result<()> {
     let raw_supported_groups = vec![0x0, 0x4, 0x0, 0x2, 0x0, 0x1d]; // 0x0, 0xa,
     let parsed_supported_groups = ExtensionSupportedEllipticCurves {
         elliptic_curves: vec![NamedCurve::X25519],
