@@ -1,8 +1,8 @@
 use super::*;
 
-use std::io::{Read, Write};
-
+use anyhow::Result;
 use byteorder::{BigEndian, ReadBytesExt, WriteBytesExt};
+use std::io::{Read, Write};
 
 // msg_len for Handshake messages assumes an extra 12 bytes for
 // sequence, Fragment and version information
@@ -22,7 +22,7 @@ impl HandshakeHeader {
         1 + 3 + 2 + 3 + 3
     }
 
-    pub fn marshal<W: Write>(&self, writer: &mut W) -> Result<(), Error> {
+    pub fn marshal<W: Write>(&self, writer: &mut W) -> Result<()> {
         writer.write_u8(self.handshake_type as u8)?;
         writer.write_u24::<BigEndian>(self.length)?;
         writer.write_u16::<BigEndian>(self.message_sequence)?;
@@ -32,7 +32,7 @@ impl HandshakeHeader {
         Ok(writer.flush()?)
     }
 
-    pub fn unmarshal<R: Read>(reader: &mut R) -> Result<Self, Error> {
+    pub fn unmarshal<R: Read>(reader: &mut R) -> Result<Self> {
         let handshake_type = reader.read_u8()?.into();
         let length = reader.read_u24::<BigEndian>()?;
         let message_sequence = reader.read_u16::<BigEndian>()?;
