@@ -1,12 +1,10 @@
-use crate::error::Error;
-
 use rand::Rng;
 
+use anyhow::Result;
+use byteorder::{BigEndian, ReadBytesExt, WriteBytesExt};
 use std::io::{Read, Write};
 use std::time::{Duration, SystemTime};
 
-use byteorder::{BigEndian, ReadBytesExt, WriteBytesExt};
-
 pub const RANDOM_BYTES_LENGTH: usize = 28;
 pub const HANDSHAKE_RANDOM_LENGTH: usize = RANDOM_BYTES_LENGTH + 4;
 
@@ -31,7 +29,7 @@ impl HandshakeRandom {
         4 + RANDOM_BYTES_LENGTH
     }
 
-    pub fn marshal<W: Write>(&self, writer: &mut W) -> Result<(), Error> {
+    pub fn marshal<W: Write>(&self, writer: &mut W) -> Result<()> {
         let secs = match self.gmt_unix_time.duration_since(SystemTime::UNIX_EPOCH) {
             Ok(d) => d.as_secs() as u32,
             Err(_) => 0,
@@ -42,7 +40,7 @@ impl HandshakeRandom {
         Ok(writer.flush()?)
     }
 
-    pub fn unmarshal<R: Read>(reader: &mut R) -> Result<Self, Error> {
+    pub fn unmarshal<R: Read>(reader: &mut R) -> Result<Self> {
         let secs = reader.read_u32::<BigEndian>()?;
         let gmt_unix_time = if let Some(unix_time) =
             SystemTime::UNIX_EPOCH.checked_add(Duration::new(secs as u64, 0))
